Class: Renjin::ComplexVector

Inherits:
Vector show all
Defined in:
lib/JRubyR/vector.rb

Instance Attribute Summary

Attributes inherited from Vector

#mdarray

Attributes included from RBSexp

#attr, #rvar, #scope, #sexp

Instance Method Summary collapse

Methods inherited from Vector

#!, #!=, #%, #&, #*, #**, #+, #+@, #-, #-@, #/, #<, #<=, #==, #>, #>=, #as__character, #as__complex, #as__double, #as__integer, #as__mdarray, #atomic?, #character?, #coerce, #complex?, #double?, #eq, #get, #gt, #gz, #initialize, #int_div, #integer?, #l_and, #l_or, #logical?, #numeric?, #xor, #|

Methods included from Index

#[], #[]=, #each, #length, #method_missing, #parse

Methods inherited from RubySexp

build, #fassign, #initialize, #to_string

Methods included from RBSexp

#destroy, #ncol, #nrow, #pp, #print, #r, #rclass, #sexp?, #typeof, #unbind

Constructor Details

This class inherits a constructor from Renjin::Vector

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Renjin::Index

Instance Method Details

#argObject


Returns a vector with the argument of this complex vector




479
480
481
# File 'lib/JRubyR/vector.rb', line 479

def arg
  R.Arg(self)
end

#conjObject


Returns a vector with the conjugate of this complex vector




487
488
489
# File 'lib/JRubyR/vector.rb', line 487

def conj
  R.Conj(self)
end

#imObject


Returns a vector with the imaginary part of this vector




463
464
465
# File 'lib/JRubyR/vector.rb', line 463

def im
  R.Im(self)
end

#modObject


Returns a vector with the modulus of this vector




471
472
473
# File 'lib/JRubyR/vector.rb', line 471

def mod
  R.Mod(self)
end

#reObject


Returns a vector with the real part of this vector




455
456
457
# File 'lib/JRubyR/vector.rb', line 455

def re
  R.Re(self)
end